import pandas as pd
import numpy as np
import glob
import sys
import matplotlib.pyplot as plt
import os

#function to label matplotlib axes
def label_point(x, y, val, ax,s):
    a = pd.concat({'x': x, 'y': y, 'val': val}, axis=1)
    for i, point in a.iterrows():
        ax.text(point['x'], point['y'], str(point['val']),fontsize=s)

rich_iso=np.load('rich_iso.npy',allow_pickle=True)
poor_iso=np.load('poor_iso.npy',allow_pickle=True)
rich_ID=np.load('rich_ID.npy',allow_pickle=True)
poor_ID=np.load('poor_ID.npy',allow_pickle=True)

table=pd.read_stata('T_econ.dta')

#plot the marginal effects estimated from the country level partition
IDr=pd.unique(table.loc[table.iso.isin(rich_iso)].ID)
IDp=pd.unique(table.loc[table.iso.isin(poor_iso)].ID)

Tdifr=[]
Tdifp=[]

for i in range(len(IDr)):
        ID=IDr[i]
        if any(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m']):
                Tdifr.append(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m'].iloc[0])

for i in range(len(IDp)):
        ID=IDp[i]
        if any(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m']):
                Tdifp.append(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m'].iloc[0])

#export the above tables (subtables of table based on rich, poor, called "fitter") to R where you can run the models and calculate the marginal effects and their confidence intervals. This is done in ME_CI2.R

#marginal effects plots for national level partitioning 
#for Fig 4
Rdydx=pd.read_csv('from_R/iso_part_rich_dydx.csv')
Pdydx=pd.read_csv('from_R/iso_part_poor_dydx.csv')
R_upr=pd.read_csv('from_R/iso_part_rich_ID_clust_upr.csv')
R_lwr=pd.read_csv('from_R/iso_part_rich_ID_clust_lwr.csv')
P_upr=pd.read_csv('from_R/iso_part_poor_ID_clust_upr.csv')
P_lwr=pd.read_csv('from_R/iso_part_poor_ID_clust_lwr.csv')
x=np.linspace(0,50,1000)

del Pdydx['Unnamed: 0']
del Rdydx['Unnamed: 0']

c_label=['ESP','MAR','USA','CHN','RUS','CAN','KEN','ECU']
x_pos=[]
for i in range(len(c_label)):
        x_pos.append(table.loc[table.iso==c_label[i],'T5_seas_diff_m'].mean())
y_pos=[]
for i in range(len(x_pos)):
        if c_label[i] in rich_iso:
                y_pos.append(Rdydx.iloc[np.where(abs(x-x_pos[i])==min(abs(x-x_pos[i])))[0][0]][0])
        #       y_pos.append(-10+x_pos[i]*0.3)
        else:
                y_pos.append(Pdydx.iloc[np.where(abs(x-x_pos[i])==min(abs(x-x_pos[i])))[0][0]][0])
        #       y_pos.append(-16+x_pos[i]*0.3)  

label=pd.DataFrame(index=c_label)
label['c']=c_label
label['x']=x_pos
label['y']=y_pos
label['y']=label['y']*100+0.7

C=u'\N{DEGREE SIGN}' + 'C'
cm=1/2.54
fontsize=7
family='Helvetica'
plt.close()
fig, axes = plt.subplots(1,1,figsize=(8*cm,8*cm))
col1='royalblue'
col2='indianred'
axes.plot(x,Rdydx['x']*100,col1,label='Above-median National Income')
axes.plot(x,Pdydx['x']*100,col2,label='Below-median National Income')
axes.fill_between(x,R_lwr['x']*100,R_upr['x']*100,color=col1,alpha=0.1)
axes.fill_between(x,P_lwr['x']*100,P_upr['x']*100,color=col2,alpha=0.1)
axes.set_ylim(ymin=-15,ymax=5)
axes.set_yticks([-15,-10,-5,0,5])
axes.set_xlim(xmin=0,xmax=50)
axes.set_xticklabels(['0' + C,'10' + C,'20'+C,'30'+C,'40'+C,'50'+C])
axes.axhline(y=0,c='k',ls='--')
ax2=axes.twinx()
axes.legend(loc=2,prop={'size': fontsize})
ax2.hist(Tdifr,bins=70,color=col1,alpha=0.8)
ax2.hist(Tdifp,bins=70,color=col2,alpha=0.8)
ax2.set_ylim(ymin=0,ymax=150)
ax2.tick_params(axis='y',which='both',left=False,right=False,labelleft=False,labelright=False)
label_point(label['x'],label['y'],label['c'],axes,fontsize)
axes.set_xlabel('Seasonal temperature difference',fontsize=fontsize)
axes.set_ylabel('Marginal change in growth rate (% points)',fontsize=fontsize)
axes.yaxis.set_label_position('left')
axes.tick_params(labelsize=fontsize)
plt.savefig('Fig_4.pdf',dpi=600,bbox_inches = 'tight',pad_inches = 0.05)
plt.close()
#make double plot

#use results from regional level partitioning
#for Fig S5
IDr=pd.unique(table.loc[table.ID.isin(rich_ID)].ID)
IDp=pd.unique(table.loc[table.ID.isin(poor_ID)].ID)

Tdifr=[]
Tdifp=[]

for i in range(len(IDr)):
        ID=IDr[i]
        if any(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m']):
                Tdifr.append(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m'].iloc[0])

for i in range(len(IDp)):
        ID=IDp[i]
        if any(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m']):
                Tdifp.append(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m'].iloc[0])

Rdydx=pd.read_csv('from_R/ID_part_rich_dydx.csv')
Pdydx=pd.read_csv('from_R/ID_part_poor_dydx.csv')
R_upr=pd.read_csv('from_R/ID_part_rich_ID_clust_upr.csv')
R_lwr=pd.read_csv('from_R/ID_part_rich_ID_clust_lwr.csv')
P_upr=pd.read_csv('from_R/ID_part_poor_ID_clust_upr.csv')
P_lwr=pd.read_csv('from_R/ID_part_poor_ID_clust_lwr.csv')
x=np.linspace(0,50,1000)

del Pdydx['Unnamed: 0']
del Rdydx['Unnamed: 0']

c_label=['ESP','MAR','USA','CHN','RUS','CAN','KEN','ECU']
x_pos=[]
for i in range(len(c_label)):
        x_pos.append(table.loc[table.iso==c_label[i],'T5_seas_diff_m'].mean())
y_pos=[]
for i in range(len(x_pos)):
        if c_label[i] in rich_iso:
                y_pos.append(Rdydx.iloc[np.where(abs(x-x_pos[i])==min(abs(x-x_pos[i])))[0][0]][0])
        #       y_pos.append(-10+x_pos[i]*0.3)
        else:
                y_pos.append(Pdydx.iloc[np.where(abs(x-x_pos[i])==min(abs(x-x_pos[i])))[0][0]][0])
        #       y_pos.append(-16+x_pos[i]*0.3)  

label=pd.DataFrame(index=c_label)
label['c']=c_label
label['x']=x_pos
label['y']=y_pos
label['y']=label['y']*100+0.7

#plotting Fig S5
C=u'\N{DEGREE SIGN}' + 'C'
fontsize=7
family='Helvetica'
plt.close()
fig, axes = plt.subplots(1,1,figsize=(8*cm,8*cm))
col1='royalblue'
col2='indianred'
axes.plot(x,Rdydx['x']*100,col1,label='Above-median Regional Income')
axes.plot(x,Pdydx['x']*100,col2,label='Below-median Regional Income')
axes.fill_between(x,R_lwr['x']*100,R_upr['x']*100,color=col1,alpha=0.1)
axes.fill_between(x,P_lwr['x']*100,P_upr['x']*100,color=col2,alpha=0.1)
axes.set_ylim(ymin=-15,ymax=5)
axes.set_yticks([-15,-10,-5,0,5])
axes.set_xlim(xmin=0,xmax=50)
axes.set_xticklabels(['0' + C,'10' + C,'20'+C,'30'+C,'40'+C,'50'+C])
axes.axhline(y=0,c='k',ls='--')
ax2=axes.twinx()
axes.legend(loc=2,prop={'size': fontsize})
ax2.hist(Tdifr,bins=70,color=col1,alpha=0.8)
ax2.hist(Tdifp,bins=70,color=col2,alpha=0.8)
ax2.set_ylim(ymin=0,ymax=150)
ax2.tick_params(axis='y',which='both',left=False,right=False,labelleft=False,labelright=False)
label_point(label['x'],label['y'],label['c'],axes,fontsize)
axes.set_xlabel('Seasonal temperature difference',fontsize=fontsize)
axes.set_ylabel('Marginal change in growth rate (%-points)',fontsize=fontsize)
axes.yaxis.set_label_position('left')
axes.tick_params(labelsize=fontsize)
plt.savefig('Fig_S5.pdf',dpi=600,bbox_inches = 'tight',pad_inches = 0.05)
plt.close()

#also make similar plot without partitions 
#plotting Fig S1
dydx=pd.read_csv('from_R/main_dydx.csv')
upr=pd.read_csv('from_R/main_ID_clust_upr.csv')
lwr=pd.read_csv('from_R/main_ID_clust_lwr.csv')
x=np.linspace(0,50,1000)

Tdif=[]
IDlist=pd.unique(table.ID)
for i in range(len(IDlist)):
        ID=IDlist[i]
        if any(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m']):
                Tdif.append(table.loc[(table.ID==ID) & (~table.T5_seas_diff_m.isnull()),'T5_seas_diff_m'].iloc[0])
cm=1/2.54
fontsize=7
plt.close()
fig, axes = plt.subplots(1,1,figsize=(10*cm,10*cm))
col1='seagreen'
col2='tan'
axes.plot(x,dydx['x']*100,col1,label='Marginal effects with 95% CI')
axes.fill_between(x,lwr['x']*100,upr['x']*100,color=col1,alpha=0.1)
axes.set_ylim(ymin=-15,ymax=5)
axes.set_xlim(xmin=0,xmax=50)
axes.axhline(y=0,c='k',ls='--')
#axes.legend(loc=2,prop={'size': fontsize})
ax2=axes.twinx()
ax2.hist(Tdif,bins=70,color=col2,alpha=0.6,label='Density of observational data')
ax2.legend(loc=3,prop={'size': fontsize})
ax2.set_ylim(ymin=0,ymax=150)
ax2.tick_params(axis='y',which='both',left=False,right=False,labelleft=False,labelright=False)
axes.set_xlabel('Seasonal temperature difference (C)',fontsize=fontsize)
axes.set_ylabel('Marginal change in growth rate (%-points)',fontsize=fontsize)
axes.yaxis.set_label_position('left')
axes.tick_params(labelsize=fontsize)
plt.savefig('Fig_S1.pdf',dpi=600,bbox_inches = 'tight',pad_inches = 0.05)
plt.close()


